package com.dcs.hnyz.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.dcs.hnyz.domain.TemplatePage;

/**
 * 模板页管理Mapper接口
 * 
 * @author hmy
 * @date 2025-04-30
 */
public interface TemplatePageMapper extends BaseMapper<TemplatePage>
{
    /**
     * 查询模板页管理
     * 
     * @param pageId 模板页管理主键
     * @return 模板页管理
     */
    public TemplatePage selectTemplatePageByPageId(Long pageId);

    /**
     * 查询模板页管理列表
     * 
     * @param templatePage 模板页管理
     * @return 模板页管理集合
     */
    public List<TemplatePage> selectTemplatePageList(TemplatePage templatePage);

    /**
     * 新增模板页管理
     * 
     * @param templatePage 模板页管理
     * @return 结果
     */
    public int insertTemplatePage(TemplatePage templatePage);

    /**
     * 修改模板页管理
     * 
     * @param templatePage 模板页管理
     * @return 结果
     */
    public int updateTemplatePage(TemplatePage templatePage);

    /**
     * 删除模板页管理
     * 
     * @param pageId 模板页管理主键
     * @return 结果
     */
    public int deleteTemplatePageByPageId(Long pageId);

    /**
     * 批量删除模板页管理
     * 
     * @param pageIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTemplatePageByPageIds(Long[] pageIds);
}
