package com.dcs.hnyz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.dcs.common.annotation.Log;
import com.dcs.common.core.controller.BaseController;
import com.dcs.common.core.domain.AjaxResult;
import com.dcs.common.enums.BusinessType;
import com.dcs.hnyz.domain.TemplatePage;
import com.dcs.hnyz.service.ITemplatePageService;
import com.dcs.common.utils.poi.ExcelUtil;
import com.dcs.common.core.page.TableDataInfo;

/**
 * 模板页管理Controller
 *
 * @author hmy
 * @date 2025-04-30
 */
@Api(tags = "模板页管理")
@RestController
@RequestMapping("/hnyz/templatePage")
public class TemplatePageController extends BaseController {
    @Autowired
    private ITemplatePageService templatePageService;

    /**
     * 查询模板页管理列表
     */
    @ApiOperation("查询模板页管理列表")
    @PreAuthorize("@ss.hasPermi('hnyz:templatePage:list')")
    @GetMapping("/list")
    public TableDataInfo list(@ApiParam("模版页参数") TemplatePage templatePage) {
        startPage();
        List<TemplatePage> list = templatePageService.selectTemplatePageList(templatePage);
        return getDataTable(list);
    }

    /**
     * 获取模版页列表，用于下拉框
     */
    @ApiOperation("获取模版页列表，用于下拉框")
    @GetMapping("/listForSelect")
    public AjaxResult listForSelect() {
        List<TemplatePage> list = templatePageService.selectTemplatePageList(null);
        return AjaxResult.success(list);
    }

    /**
     * 导出模板页管理列表
     */
    @PreAuthorize("@ss.hasPermi('hnyz:templatePage:export')")
    @Log(title = "模板页管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TemplatePage templatePage) {
        List<TemplatePage> list = templatePageService.selectTemplatePageList(templatePage);
        ExcelUtil<TemplatePage> util = new ExcelUtil<TemplatePage>(TemplatePage.class);
        util.exportExcel(response, list, "模板页管理数据");
    }

    /**
     * 获取模板页管理详细信息
     */
    @ApiOperation("获取模板页管理详细信息")
    @PreAuthorize("@ss.hasPermi('hnyz:templatePage:query')")
    @GetMapping(value = "/{pageId}")
    public AjaxResult getInfo(@ApiParam("模版页id") @PathVariable("pageId") Long pageId) {
        return success(templatePageService.selectTemplatePageByPageId(pageId));
    }

    /**
     * 新增模板页管理
     */
    @ApiOperation("新增模板页管理")
    @PreAuthorize("@ss.hasPermi('hnyz:templatePage:add')")
    @Log(title = "模板页管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TemplatePage templatePage) {
        return toAjax(templatePageService.insertTemplatePage(templatePage));
    }

    /**
     * 修改模板页管理
     */
    @ApiOperation("修改模板页管理")
    @PreAuthorize("@ss.hasPermi('hnyz:templatePage:edit')")
    @Log(title = "模板页管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TemplatePage templatePage) {
        return toAjax(templatePageService.updateTemplatePage(templatePage));
    }

    /**
     * 删除模板页管理
     */
    @ApiOperation("删除模板页管理")
    @PreAuthorize("@ss.hasPermi('hnyz:templatePage:remove')")
    @Log(title = "模板页管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{pageIds}")
    public AjaxResult remove(@PathVariable Long[] pageIds) {
        return toAjax(templatePageService.deleteTemplatePageByPageIds(pageIds));
    }

    /**
     * 修改启用状态
     */
    @PreAuthorize("@ss.hasPermi('hnyz:templatePage:edit')")
    @Log(title = "模板页管理", businessType = BusinessType.UPDATE)
    @PutMapping("/changeStatus")
    public AjaxResult changeStatus(@RequestBody TemplatePage templatePage) {
        return toAjax(templatePageService.updateTemplatePage(templatePage));
    }
}
